<?php

/**
 * GiroCheckout: Payment gateway for Opencart
 * 
 * @author GiroSolution AG
 * @link http://www.girosolution.de
 * @package GiroCheckout
 * @copyright Copyright (c) 2015, GiroSolution AG
 */
class ControllerPaymentGcDirectDebit extends Controller {

    private $error = array();

    public function index() {
        $this->load->language('payment/gc_directdebit');

        $this->document->setTitle($this->language->get('heading_title'));

        $this->load->model('setting/setting');

        if (($this->request->server['REQUEST_METHOD'] == 'POST') && ($this->validate())) {
            $this->model_setting_setting->editSetting('gc_directdebit', $this->request->post);

            $this->session->data['success'] = $this->language->get('text_success');

            $this->response->redirect($this->url->link('extension/payment', 'token=' . $this->session->data['token'], 'SSL'));
        }

        $data['heading_title'] = $this->language->get('heading_title');

        $data['text_edit'] = $this->language->get('text_edit');
        $data['text_enabled'] = $this->language->get('text_enabled');
        $data['text_disabled'] = $this->language->get('text_disabled');
        $data['text_yes'] = $this->language->get('text_yes');
        $data['text_no'] = $this->language->get('text_no');
        $data['text_all_zones'] = $this->language->get('text_all_zones');

        $data['entry_merchant_id'] = $this->language->get('entry_merchant_id');
        $data['entry_project_id'] = $this->language->get('entry_project_id');
        $data['entry_secret'] = $this->language->get('entry_secret');
        $data['entry_description'] = $this->language->get('entry_description');
        $data['entry_order_status'] = $this->language->get('entry_order_status');
        $data['entry_total'] = $this->language->get('entry_total');
        $data['entry_geo_zone'] = $this->language->get('entry_geo_zone');
        $data['entry_status'] = $this->language->get('entry_status');
        $data['entry_sort_order'] = $this->language->get('entry_sort_order');

        $data['help_description'] = $this->language->get('help_description');
        $data['help_total'] = $this->language->get('help_total');

        $data['button_save'] = $this->language->get('button_save');
        $data['button_cancel'] = $this->language->get('button_cancel');

        if (isset($this->request->post['module_name_status'])) {
            $data['featured_status'] = $this->request->post['module_name_status'];
        } else {
            $data['featured_status'] = $this->config->get('module_name_status');
        }

        if (isset($this->error['warning'])) {
            $data['error_warning'] = $this->error['warning'];
        } else {
            $data['error_warning'] = '';
        }

        if (isset($this->error['merchant_id'])) {
            $data['error_merchant_id'] = $this->error['merchant_id'];
        } else {
            $data['error_merchant_id'] = '';
        }

        if (isset($this->error['project_id'])) {
            $data['error_project_id'] = $this->error['project_id'];
        } else {
            $data['error_project_id'] = '';
        }

        if (isset($this->error['secret'])) {
            $data['error_secret'] = $this->error['secret'];
        } else {
            $data['error_secret'] = '';
        }

        $data['breadcrumbs'] = array();

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_home'),
            'href' => $this->url->link('common/home', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => false
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('text_payment'),
            'href' => $this->url->link('extension/payment', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => ' :: '
        );

        $data['breadcrumbs'][] = array(
            'text' => $this->language->get('heading_title'),
            'href' => $this->url->link('payment/gc_directdebit', 'token=' . $this->session->data['token'], 'SSL'),
            'separator' => ' :: '
        );

        if (isset($this->request->get['type'])) {
            $data['type'] = $this->request->get['type'];
        } else {
            $data['type'] = '';
        }

        $data['action'] = $this->url->link('payment/gc_directdebit', 'token=' . $this->session->data['token'], 'SSL');

        $data['cancel'] = $this->url->link('extension/payment', 'token=' . $this->session->data['token'], 'SSL');

        if (isset($this->request->post['gc_directdebit_merchant_id'])) {
            $data['gc_directdebit_merchant_id'] = $this->request->post['gc_directdebit_merchant_id'];
        } else {
            $data['gc_directdebit_merchant_id'] = $this->config->get('gc_directdebit_merchant_id');
        }

        if (isset($this->request->post['gc_directdebit_project_id'])) {
            $data['gc_directdebit_project_id'] = $this->request->post['gc_directdebit_project_id'];
        } else {
            $data['gc_directdebit_project_id'] = $this->config->get('gc_directdebit_project_id');
        }

        if (isset($this->request->post['gc_directdebit_secret'])) {
            $data['gc_directdebit_secret'] = $this->request->post['gc_directdebit_secret'];
        } else {
            $data['gc_directdebit_secret'] = $this->config->get('gc_directdebit_secret');
        }

        if (isset($this->request->post['gc_directdebit_description'])) {
            $data['gc_directdebit_description'] = $this->request->post['gc_directdebit_description'];
        } else {
            $data['gc_directdebit_description'] = $this->config->get('gc_directdebit_description');
        }

        if (isset($this->request->post['gc_directdebit_total'])) {
            $data['gc_directdebit_total'] = $this->request->post['gc_directdebit_total'];
        } else {
            $data['gc_directdebit_total'] = $this->config->get('gc_directdebit_total');
        }

        if (isset($this->request->post['gc_directdebit_order_status_id'])) {
            $data['gc_directdebit_order_status_id'] = $this->request->post['gc_directdebit_order_status_id'];
        } else {

            $data['gc_directdebit_order_status_id'] = $this->config->get('gc_directdebit_order_status_id');
        }

        if (isset($this->request->post['gc_directdebit_geo_zone_id'])) {
            $data['gc_directdebit_geo_zone_id'] = $this->request->post['gc_directdebit_geo_zone_id'];
        } else {
            $data['gc_directdebit_geo_zone_id'] = $this->config->get('gc_directdebit_geo_zone_id');
        }

        if (isset($this->request->post['gc_directdebit_status'])) {
            $data['gc_directdebit_status'] = $this->request->post['gc_directdebit_status'];
        } else {
            $data['gc_directdebit_status'] = $this->config->get('gc_directdebit_status');
        }

        if (isset($this->request->post['gc_directdebit_sort_order'])) {
            $data['gc_directdebit_sort_order'] = $this->request->post['gc_directdebit_sort_order'];
        } else {
            $data['gc_directdebit_sort_order'] = $this->config->get('gc_directdebit_sort_order');
        }


        $this->load->model('localisation/order_status');

        $data['order_statuses'] = $this->model_localisation_order_status->getOrderStatuses();

        $this->load->model('localisation/geo_zone');

        $data['geo_zones'] = $this->model_localisation_geo_zone->getGeoZones();

        $data['header'] = $this->load->controller('common/header');
        $data['column_left'] = $this->load->controller('common/column_left');
        $data['footer'] = $this->load->controller('common/footer');

        $this->response->setOutput($this->load->view('payment/gc_directdebit.tpl', $data));
    }

    public function install() {
        $this->load->model('extension/extension');
    }

    public function uninstall() {
        $this->load->model('extension/extension');
        $this->load->model('setting/setting');
    }

    private function validate() {
        if (!$this->user->hasPermission('modify', 'payment/gc_directdebit')) {
            $this->error['warning'] = $this->language->get('error_permission');
        }

        if (!$this->request->post['gc_directdebit_merchant_id']) {
            $this->error['merchant_id'] = $this->language->get('error_merchant_id');
        }

        if (!$this->request->post['gc_directdebit_project_id'] && $this->request->post['gc_directdebit_status']) {
            $this->error['project_id'] = $this->language->get('error_project_id');
        }

        if (!$this->request->post['gc_directdebit_secret'] && $this->request->post['gc_directdebit_status']) {
            $this->error['secret'] = $this->language->get('error_secret');
        }

        if ($this->error && !isset($this->error['warning'])) {
            $this->error['warning'] = $this->language->get('error_warning');
        }

        if (!$this->error) {
            return true;
        } else {
            return false;
        }
    }

}
